from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MoveAction import MoveAction


class TravelAction(MoveAction):
    """The act of traveling from a fromLocation to a destination by a specified mode of transport, optionally with
     participants.

    See: https://schema.org/TravelAction
    Model depth: 4
    """

    type_: str = Field(default="TravelAction", alias="@type", const=True)
    distance: Optional[Union[List[Union["Distance", str]], "Distance", str]] = Field(
        default=None,
        description="The distance travelled, e.g. exercising or travelling.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Distance import Distance



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Class(Intangible):
    """A class, also often called a 'Type'; equivalent to rdfs:Class.

    See: https://schema.org/Class
    Model depth: 3
    """

    type_: str = Field(default="Class", alias="@type", const=True)
    supersededBy: Optional[
        Union[
            List[Union["Class", "Enumeration", "Property", str]],
            "Class",
            "Enumeration",
            "Property",
            str,
        ]
    ] = Field(
        default=None,
        description="Relates a term (i.e. a property, class or enumeration) to one that supersedes it.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Enumeration import Enumeration
    from pydantic2_schemaorg.Property import Property



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWorkSeries import CreativeWorkSeries


class MovieSeries(CreativeWorkSeries):
    """A series of movies. Included movies can be indicated with the hasPart property.

    See: https://schema.org/MovieSeries
    Model depth: 4
    """

    type_: str = Field(default="MovieSeries", alias="@type", const=True)
    trailer: Optional[Union[List[Union["VideoObject", str]], "VideoObject", str]] = (
        Field(
            default=None,
            description="The trailer of a movie or TV/radio series, season, episode, etc.",
        )
    )
    productionCompany: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The production company or studio responsible for the item, e.g. series, video game, episode etc.",
    )
    actors: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc. Actors can be associated with individual items or with a series, episode, clip.",
    )
    director: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.",
    )
    directors: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A director of e.g. TV, radio, movie, video games etc. content. Directors can be associated with individual items or with a series, episode, clip.",
    )
    actor: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.",
    )
    musicBy: Optional[
        Union[List[Union["Person", "MusicGroup", str]], "Person", "MusicGroup", str]
    ] = Field(
        default=None,
        description="The composer of the soundtrack.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.VideoObject import VideoObject
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.MusicGroup import MusicGroup



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class MapCategoryType(Enumeration):
    """An enumeration of several kinds of Map.

    See: https://schema.org/MapCategoryType
    Model depth: 4
    """

    type_: str = Field(default="MapCategoryType", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Endocrine(MedicalSpecialty):
    """A specific branch of medical science that pertains to diagnosis and treatment of disorders of endocrine glands
     and their secretions.

    See: https://schema.org/Endocrine
    Model depth: 6
    """

    type_: str = Field(default="Endocrine", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class ShippingRateSettings(StructuredValue):
    """A ShippingRateSettings represents re-usable pieces of shipping information. It is designed for publication
     on an URL that may be referenced via the [[shippingSettingsLink]] property of an [[OfferShippingDetails]].
     Several occurrences can be published, distinguished and matched (i.e. identified/referenced) by their
     different values for [[shippingLabel]].

    See: https://schema.org/ShippingRateSettings
    Model depth: 4
    """

    type_: str = Field(default="ShippingRateSettings", alias="@type", const=True)
    doesNotShip: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Indicates when shipping to a particular [[shippingDestination]] is not available.",
    )
    shippingRate: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="The shipping rate is the cost of shipping to the specified destination. Typically, the maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.",
    )
    shippingLabel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within the context of a [[shippingSettingsLink]] cross-reference).",
    )
    isUnlabelledFallback: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="This can be marked 'true' to indicate that some published [[DeliveryTimeSettings]] or [[ShippingRateSettings]] are intended to apply to all [[OfferShippingDetails]] published by the same merchant, when referenced by a [[shippingSettingsLink]] in those settings. It is not meaningful to use a 'true' value for this property alongside a transitTimeLabel (for [[DeliveryTimeSettings]]) or shippingLabel (for [[ShippingRateSettings]]), since this property is for use with unlabelled settings.",
    )
    shippingDestination: Optional[
        Union[List[Union["DefinedRegion", str]], "DefinedRegion", str]
    ] = Field(
        default=None,
        description="indicates (possibly multiple) shipping destinations. These can be defined in several ways, e.g. postalCode ranges.",
    )
    freeShippingThreshold: Optional[
        Union[
            List[Union["DeliveryChargeSpecification", "MonetaryAmount", str]],
            "DeliveryChargeSpecification",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="A monetary value above (or at) which the shipping rate becomes free. Intended to be used via an [[OfferShippingDetails]] with [[shippingSettingsLink]] matching this [[ShippingRateSettings]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedRegion import DefinedRegion
    from pydantic2_schemaorg.DeliveryChargeSpecification import (
        DeliveryChargeSpecification,
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class SolveMathAction(Action):
    """The action that takes in a math expression and directs users to a page potentially capable of solving/simplifying
     that expression.

    See: https://schema.org/SolveMathAction
    Model depth: 3
    """

    type_: str = Field(default="SolveMathAction", alias="@type", const=True)
    eduQuestionType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given. Example: "Multiple choice", "Open ended", "Flashcard".',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl, StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class TypeAndQuantityNode(StructuredValue):
    """A structured value indicating the quantity, unit of measurement, and business function of goods included
     in a bundle offer.

    See: https://schema.org/TypeAndQuantityNode
    Model depth: 4
    """

    type_: str = Field(default="TypeAndQuantityNode", alias="@type", const=True)
    amountOfThisGood: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The quantity of the goods included in the offer.",
    )
    unitCode: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.",
    )
    businessFunction: Optional[
        Union[List[Union["BusinessFunction", str]], "BusinessFunction", str]
    ] = Field(
        default=None,
        description="The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.",
    )
    unitText: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for <a href='unitCode'>unitCode</a>.",
    )
    typeOfGood: Optional[
        Union[List[Union["Service", "Product", str]], "Service", "Product", str]
    ] = Field(
        default=None,
        description="The product that this structured value is referring to.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BusinessFunction import BusinessFunction
    from pydantic2_schemaorg.Service import Service
    from pydantic2_schemaorg.Product import Product



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InformAction import InformAction


class ConfirmAction(InformAction):
    """The act of notifying someone that a future event/action is going to happen as expected. Related actions: *
     [[CancelAction]]: The antonym of ConfirmAction.

    See: https://schema.org/ConfirmAction
    Model depth: 6
    """

    type_: str = Field(default="ConfirmAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DrugPregnancyCategory import DrugPregnancyCategory


class FDAcategoryC(DrugPregnancyCategory):
    """A designation by the US FDA signifying that animal reproduction studies have shown an adverse effect on the
     fetus and there are no adequate and well-controlled studies in humans, but potential benefits may warrant
     use of the drug in pregnant women despite potential risks.

    See: https://schema.org/FDAcategoryC
    Model depth: 6
    """

    type_: str = Field(default="FDAcategoryC", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import datetime
from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
from pydantic2_schemaorg.Intangible import Intangible


class Observation(QuantitativeValue, Intangible):
    """Instances of the class [[Observation]] are used to specify observations about an entity at a particular time.
     The principal properties of an [[Observation]] are [[observationAbout]], [[measuredProperty]], [[statType]],
     [[value] and [[observationDate]] and [[measuredProperty]]. Some but not all Observations represent a
     [[QuantitativeValue]]. Quantitative observations can be about a [[StatisticalVariable]], which is an
     abstract specification about which we can make observations that are grounded at a particular location and
     time. Observations can also encode a subset of simple RDF-like statements (its observationAbout, a StatisticalVariable,
     defining the measuredPoperty; its observationAbout property indicating the entity the statement is about,
     and [[value]] ) In the context of a quantitative knowledge graph, typical properties could include [[measuredProperty]],
     [[observationAbout]], [[observationDate]], [[value]], [[unitCode]], [[unitText]], [[measurementMethod]].

    See: https://schema.org/Observation
    Model depth: 3
    """

    type_: str = Field(default="Observation", alias="@type", const=True)
    observationDate: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The observationDate of an [[Observation]].",
    )
    measurementTechnique: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description='A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable. The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery. For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory". If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMetholdEnumeration]].',
    )
    marginOfError: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="A [[marginOfError]] for an [[Observation]].",
    )
    measurementDenominator: Optional[
        Union[List[Union["StatisticalVariable", str]], "StatisticalVariable", str]
    ] = Field(
        default=None,
        description="Identifies the denominator variable when an observation represents a ratio or percentage.",
    )
    measurementQualifier: Optional[
        Union[List[Union["Enumeration", str]], "Enumeration", str]
    ] = Field(
        default=None,
        description="Provides additional qualification to an observation. For example, a GDP observation measures the Nominal value.",
    )
    variableMeasured: Optional[
        Union[
            List[
                Union[str, "Text", "Property", "StatisticalVariable", "PropertyValue"]
            ],
            str,
            "Text",
            "Property",
            "StatisticalVariable",
            "PropertyValue",
        ]
    ] = Field(
        default=None,
        description="The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].",
    )
    observationPeriod: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The length of time an Observation took place over. The format follows `P[0-9]*[Y|M|D|h|m|s]`. For example, P1Y is Period 1 Year, P3M is Period 3 Months, P3h is Period 3 hours.",
    )
    measurementMethod: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].",
    )
    observationAbout: Optional[
        Union[List[Union["Place", "Thing", str]], "Place", "Thing", str]
    ] = Field(
        default=None,
        description="The [[observationAbout]] property identifies an entity, often a [[Place]], associated with an [[Observation]].",
    )
    measuredProperty: Optional[Union[List[Union["Property", str]], "Property", str]] = (
        Field(
            default=None,
            description="The measuredProperty of an [[Observation]], typically via its [[StatisticalVariable]]. There are various kinds of applicable [[Property]]: a schema.org property, a property from other RDF-compatible systems, e.g. W3C RDF Data Cube, Data Commons, Wikidata, or schema.org extensions such as [GS1's](https://www.gs1.org/voc/?show=properties).",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MeasurementMethodEnum import MeasurementMethodEnum
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.StatisticalVariable import StatisticalVariable
    from pydantic2_schemaorg.Enumeration import Enumeration
    from pydantic2_schemaorg.Property import Property
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ActionStatusType import ActionStatusType


class FailedActionStatus(ActionStatusType):
    """An action that failed to complete. The action's error property and the HTTP return code contain more information
     about the failure.

    See: https://schema.org/FailedActionStatus
    Model depth: 6
    """

    type_: str = Field(default="FailedActionStatus", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class MoneyTransfer(TransferAction):
    """The act of transferring money from one place to another place. This may occur electronically or physically.

    See: https://schema.org/MoneyTransfer
    Model depth: 4
    """

    type_: str = Field(default="MoneyTransfer", alias="@type", const=True)
    amount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The amount of money.",
    )
    beneficiaryBank: Optional[
        Union[
            List[Union[str, "Text", "BankOrCreditUnion"]],
            str,
            "Text",
            "BankOrCreditUnion",
        ]
    ] = Field(
        default=None,
        description="A bank or bank’s branch, financial institution or international financial institution operating the beneficiary’s bank account or releasing funds for the beneficiary.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BankOrCreditUnion import BankOrCreditUnion



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OfferItemCondition import OfferItemCondition


class RefurbishedCondition(OfferItemCondition):
    """Indicates that the item is refurbished.

    See: https://schema.org/RefurbishedCondition
    Model depth: 5
    """

    type_: str = Field(default="RefurbishedCondition", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DataType import DataType


class Boolean(DataType):
    """Boolean: True or False.

    See: https://schema.org/Boolean
    Model depth: 5
    """

    type_: str = Field(default="Boolean", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTest import MedicalTest


class PathologyTest(MedicalTest):
    """A medical test performed by a laboratory that typically involves examination of a tissue sample by a pathologist.

    See: https://schema.org/PathologyTest
    Model depth: 4
    """

    type_: str = Field(default="PathologyTest", alias="@type", const=True)
    tissueSample: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The type of tissue sample required for the test.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class ReturnAction(TransferAction):
    """The act of returning to the origin that which was previously received (concrete objects) or taken (ownership).

    See: https://schema.org/ReturnAction
    Model depth: 4
    """

    type_: str = Field(default="ReturnAction", alias="@type", const=True)
    recipient: Optional[
        Union[
            List[Union["Organization", "Audience", "Person", "ContactPoint", str]],
            "Organization",
            "Audience",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the receiving end of the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ContactPoint import ContactPoint



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class AdvertiserContentArticle(Article):
    """An [[Article]] that an external entity has paid to place or to produce to its specifications. Includes [advertorials](https://en.wikipedia.org/wiki/Advertorial),
     sponsored content, native advertising and other paid content.

    See: https://schema.org/AdvertiserContentArticle
    Model depth: 4
    """

    type_: str = Field(default="AdvertiserContentArticle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class SelfCareHealthAspect(HealthAspectEnumeration):
    """Self care actions or measures that can be taken to sooth, health or avoid a topic. This may be carried at home
     and can be carried/managed by the person itself.

    See: https://schema.org/SelfCareHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="SelfCareHealthAspect", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Conversation(CreativeWork):
    """One or more messages between organizations or people on a particular topic. Individual messages can be linked
     to the conversation with isPartOf or hasPart properties.

    See: https://schema.org/Conversation
    Model depth: 3
    """

    type_: str = Field(default="Conversation", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Seat(Intangible):
    """Used to describe a seat, such as a reserved seat in an event reservation.

    See: https://schema.org/Seat
    Model depth: 3
    """

    type_: str = Field(default="Seat", alias="@type", const=True)
    seatRow: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The row location of the reserved seat (e.g., B).",
    )
    seatSection: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The section location of the reserved seat (e.g. Orchestra).",
    )
    seatNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The location of the reserved seat (e.g., 27).",
    )
    seatingType: Optional[
        Union[
            List[Union[str, "Text", "QualitativeValue"]],
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="The type/class of the seat.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat
from datetime import datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Reservation(Intangible):
    """Describes a reservation for travel, dining or an event. Some reservations require tickets. Note: This type
     is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual
     confirmations of reservations. For offers of tickets, restaurant reservations, flights, or rental cars,
     use [[Offer]].

    See: https://schema.org/Reservation
    Model depth: 3
    """

    type_: str = Field(default="Reservation", alias="@type", const=True)
    priceCurrency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency of the price, or a price component when attached to [[PriceSpecification]] and its subtypes. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    totalPrice: Optional[
        Union[
            List[
                Union[
                    StrictInt, StrictFloat, "Number", str, "Text", "PriceSpecification"
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
            "PriceSpecification",
        ]
    ] = Field(
        default=None,
        description="The total price for the reservation or ticket, including applicable taxes, shipping, etc. Usage guidelines: * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )
    bookingTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date and time the reservation was booked.",
    )
    underName: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The person or organization the reservation or ticket is for.",
    )
    bookingAgent: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="'bookingAgent' is an out-dated term indicating a 'broker' that serves as a booking agent.",
    )
    reservedTicket: Optional[Union[List[Union["Ticket", str]], "Ticket", str]] = Field(
        default=None,
        description="A ticket associated with the reservation.",
    )
    reservationStatus: Optional[
        Union[List[Union["ReservationStatusType", str]], "ReservationStatusType", str]
    ] = Field(
        default=None,
        description="The current status of the reservation.",
    )
    broker: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.",
    )
    programMembershipUsed: Optional[
        Union[List[Union["ProgramMembership", str]], "ProgramMembership", str]
    ] = Field(
        default=None,
        description="Any membership in a frequent flyer, hotel loyalty program, etc. being applied to the reservation.",
    )
    modifiedTime: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The date and time the reservation was modified.",
    )
    reservationFor: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The thing -- flight, event, restaurant, etc. being reserved.",
    )
    provider: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.",
    )
    reservationId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A unique identifier for the reservation.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Ticket import Ticket
    from pydantic2_schemaorg.ReservationStatusType import ReservationStatusType
    from pydantic2_schemaorg.ProgramMembership import ProgramMembership
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Trip import Trip


class TrainTrip(Trip):
    """A trip on a commercial train line.

    See: https://schema.org/TrainTrip
    Model depth: 4
    """

    type_: str = Field(default="TrainTrip", alias="@type", const=True)
    arrivalPlatform: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The platform where the train arrives.",
    )
    arrivalStation: Optional[
        Union[List[Union["TrainStation", str]], "TrainStation", str]
    ] = Field(
        default=None,
        description="The station where the train trip ends.",
    )
    departureStation: Optional[
        Union[List[Union["TrainStation", str]], "TrainStation", str]
    ] = Field(
        default=None,
        description="The station from which the train departs.",
    )
    departurePlatform: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The platform from which the train departs.",
    )
    trainNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unique identifier for the train.",
    )
    trainName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The name of the train (e.g. The Orient Express).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.TrainStation import TrainStation



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PlanAction import PlanAction


class CancelAction(PlanAction):
    """The act of asserting that a future event/action is no longer going to happen. Related actions: * [[ConfirmAction]]:
     The antonym of CancelAction.

    See: https://schema.org/CancelAction
    Model depth: 5
    """

    type_: str = Field(default="CancelAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class ExchangeRateSpecification(StructuredValue):
    """A structured value representing exchange rate.

    See: https://schema.org/ExchangeRateSpecification
    Model depth: 4
    """

    type_: str = Field(default="ExchangeRateSpecification", alias="@type", const=True)
    currency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency in which the monetary amount is expressed. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )
    currentExchangeRate: Optional[
        Union[List[Union["UnitPriceSpecification", str]], "UnitPriceSpecification", str]
    ] = Field(
        default=None,
        description="The current price of a currency.",
    )
    exchangeRateSpread: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The difference between the price at which a broker or other intermediary buys and sells foreign currency.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.UnitPriceSpecification import UnitPriceSpecification
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class DigitalDocument(CreativeWork):
    """An electronic file or document.

    See: https://schema.org/DigitalDocument
    Model depth: 3
    """

    type_: str = Field(default="DigitalDocument", alias="@type", const=True)
    hasDigitalDocumentPermission: Optional[
        Union[
            List[Union["DigitalDocumentPermission", str]],
            "DigitalDocumentPermission",
            str,
        ]
    ] = Field(
        default=None,
        description='A permission related to the access to this document (e.g. permission to read or write an electronic document). For a public document, specify a grantee with an Audience with audienceType equal to "public".',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DigitalDocumentPermission import DigitalDocumentPermission



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DataType import DataType


class Number(DataType):
    """Data type: Number. Usage guidelines: * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT
     NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E))
     rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.

    See: https://schema.org/Number
    Model depth: 5
    """

    type_: str = Field(default="Number", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentStatusType import PaymentStatusType


class PaymentDue(PaymentStatusType):
    """The payment is due, but still within an acceptable time to be received.

    See: https://schema.org/PaymentDue
    Model depth: 6
    """

    type_: str = Field(default="PaymentDue", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TherapeuticProcedure import TherapeuticProcedure


class MedicalTherapy(TherapeuticProcedure):
    """Any medical intervention designed to prevent, treat, and cure human diseases and medical conditions, including
     both curative and palliative therapies. Medical therapies are typically processes of care relying upon
     pharmacotherapy, behavioral therapy, supportive therapy (with fluid or nutrition for example), or detoxification
     (e.g. hemodialysis) aimed at improving or preventing a health condition.

    See: https://schema.org/MedicalTherapy
    Model depth: 5
    """

    type_: str = Field(default="MedicalTherapy", alias="@type", const=True)
    seriousAdverseOutcome: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.",
    )
    contraindication: Optional[
        Union[
            List[Union[str, "Text", "MedicalContraindication"]],
            str,
            "Text",
            "MedicalContraindication",
        ]
    ] = Field(
        default=None,
        description="A contraindication for this therapy.",
    )
    duplicateTherapy: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A therapy that duplicates or overlaps this one.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalContraindication import MedicalContraindication



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.TradeAction import TradeAction


class PreOrderAction(TradeAction):
    """An agent orders a (not yet released) object/product/service to be delivered/sent.

    See: https://schema.org/PreOrderAction
    Model depth: 4
    """

    type_: str = Field(default="PreOrderAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EventStatusType import EventStatusType


class EventScheduled(EventStatusType):
    """The event is taking place or has taken place on the startDate as scheduled. Use of this value is optional, as
     it is assumed by default.

    See: https://schema.org/EventScheduled
    Model depth: 6
    """

    type_: str = Field(default="EventScheduled", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Comment import Comment


class Question(Comment):
    """A specific question - e.g. from a user seeking answers online, or collected in a Frequently Asked Questions
     (FAQ) document.

    See: https://schema.org/Question
    Model depth: 4
    """

    type_: str = Field(default="Question", alias="@type", const=True)
    parentItem: Optional[
        Union[
            List[Union["Comment", "CreativeWork", str]], "Comment", "CreativeWork", str
        ]
    ] = Field(
        default=None,
        description="The parent of a question, answer or item in general. Typically used for Q/A discussion threads e.g. a chain of comments with the first comment being an [[Article]] or other [[CreativeWork]]. See also [[comment]] which points from something to a comment about it.",
    )
    suggestedAnswer: Optional[
        Union[List[Union["Answer", "ItemList", str]], "Answer", "ItemList", str]
    ] = Field(
        default=None,
        description="An answer (possibly one of several, possibly incorrect) to a Question, e.g. on a Question/Answer site.",
    )
    eduQuestionType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates the format of question being given. Example: "Multiple choice", "Open ended", "Flashcard".',
    )
    answerCount: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of answers this question has received.",
    )
    acceptedAnswer: Optional[
        Union[List[Union["Answer", "ItemList", str]], "Answer", "ItemList", str]
    ] = Field(
        default=None,
        description="The answer(s) that has been accepted as best, typically on a Question/Answer site. Sites vary in their selection mechanisms, e.g. drawing on community opinion and/or the view of the Question author.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Comment import Comment
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Answer import Answer
    from pydantic2_schemaorg.ItemList import ItemList
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Integer import Integer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType


class OneTimePayments(GovernmentBenefitsType):
    """OneTimePayments: this is a benefit for one-time payments for individuals.

    See: https://schema.org/OneTimePayments
    Model depth: 5
    """

    type_: str = Field(default="OneTimePayments", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date, datetime, time
from pydantic.v1 import AnyUrl, StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.Thing import Thing


class Event(Thing):
    """An event happening at a certain time and location, such as a concert, lecture, or festival. Ticketing information
     may be added via the [[offers]] property. Repeated events may be structured as separate Event objects.

    See: https://schema.org/Event
    Model depth: 2
    """

    type_: str = Field(default="Event", alias="@type", const=True)
    audience: Optional[Union[List[Union["Audience", str]], "Audience", str]] = Field(
        default=None,
        description="An intended audience, i.e. a group for whom something was created.",
    )
    composer: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The person or organization who wrote a composition, or who is the composer of a work performed at some event.",
    )
    duration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    subEvent: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference.",
    )
    funder: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports (sponsors) something through some kind of financial contribution.",
    )
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    subEvents: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Events that are a part of this event. For example, a conference event includes many presentations, each subEvents of the conference.",
    )
    maximumAttendeeCapacity: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The total number of individuals that may attend an event or venue.",
    )
    inLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]].",
    )
    attendees: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person attending the event.",
    )
    performers: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The main performer or performers of the event&#x2014;for example, a presenter, musician, or actor.",
    )
    director: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.",
    )
    aggregateRating: Optional[
        Union[List[Union["AggregateRating", str]], "AggregateRating", str]
    ] = Field(
        default=None,
        description="The overall rating, based on a collection of reviews or ratings, of the item.",
    )
    about: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The subject matter of the content.",
    )
    keywords: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DefinedTerm"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.",
    )
    workPerformed: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="A work performed in some event, for example a play performed in a TheaterEvent.",
    )
    isAccessibleForFree: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="A flag to signal that the item, event, or place is accessible for free.",
    )
    remainingAttendeeCapacity: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of attendee places for an event that remain unallocated.",
    )
    translator: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event.",
    )
    recordedIn: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="The CreativeWork that captured all or part of this Event.",
    )
    attendee: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization attending the event.",
    )
    maximumPhysicalAttendeeCapacity: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The maximum physical attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OfflineEventAttendanceMode]] (or the offline aspects, in the case of a [[MixedEventAttendanceMode]]).",
    )
    performer: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A performer at the event&#x2014;for example, a presenter, musician, musical group or actor.",
    )
    typicalAgeRange: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The typical expected age range, e.g. '7-9', '11-'.",
    )
    maximumVirtualAttendeeCapacity: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The maximum virtual attendee capacity of an [[Event]] whose [[eventAttendanceMode]] is [[OnlineEventAttendanceMode]] (or the online aspects, in the case of a [[MixedEventAttendanceMode]]).",
    )
    actor: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.",
    )
    sponsor: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.",
    )
    eventAttendanceMode: Optional[
        Union[
            List[Union["EventAttendanceModeEnumeration", str]],
            "EventAttendanceModeEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="The eventAttendanceMode of an event indicates whether it occurs online, offline, or a mix.",
    )
    location: Optional[
        Union[
            List[Union[str, "Text", "Place", "PostalAddress", "VirtualLocation"]],
            str,
            "Text",
            "Place",
            "PostalAddress",
            "VirtualLocation",
        ]
    ] = Field(
        default=None,
        description="The location of, for example, where an event is happening, where an organization is located, or where an action takes place.",
    )
    review: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="A review of the item.",
    )
    superEvent: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent.",
    )
    eventSchedule: Optional[Union[List[Union["Schedule", str]], "Schedule", str]] = (
        Field(
            default=None,
            description="Associates an [[Event]] with a [[Schedule]]. There are circumstances where it is preferable to share a schedule for a series of repeating events rather than data on the individual events themselves. For example, a website or application might prefer to publish a schedule for a weekly gym class rather than provide data on every event. A schedule could be processed by applications to add forthcoming events to a calendar. An [[Event]] that is associated with a [[Schedule]] using this property should not have [[startDate]] or [[endDate]] properties. These are instead defined within the associated [[Schedule]], this avoids any ambiguity for clients using the data. The property might have repeated values to specify different schedules, e.g. for different months or seasons.",
        )
    )
    contributor: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A secondary contributor to the CreativeWork or Event.",
    )
    workFeatured: Optional[
        Union[List[Union["CreativeWork", str]], "CreativeWork", str]
    ] = Field(
        default=None,
        description="A work featured in some event, e.g. exhibited in an ExhibitionEvent. Specific subproperties are available for workPerformed (e.g. a play), or a workPresented (a Movie at a ScreeningEvent).",
    )
    doorTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The time admission will commence.",
    )
    previousStartDate: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="Used in conjunction with eventStatus for rescheduled or cancelled events. This property contains the previously scheduled start date. For rescheduled events, the startDate property should be used for the newly scheduled start date. In the (rare) case of an event that has been postponed and rescheduled multiple times, this field may be repeated.",
    )
    eventStatus: Optional[
        Union[List[Union["EventStatusType", str]], "EventStatusType", str]
    ] = Field(
        default=None,
        description="An eventStatus of an event represents its status; particularly useful when an event is cancelled or rescheduled.",
    )
    offers: Optional[
        Union[List[Union["Demand", "Offer", str]], "Demand", "Offer", str]
    ] = Field(
        default=None,
        description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    funding: Optional[Union[List[Union["Grant", str]], "Grant", str]] = Field(
        default=None,
        description="A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].",
    )
    organizer: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An organizer of an Event.",
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language
    from pydantic2_schemaorg.AggregateRating import AggregateRating
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.EventAttendanceModeEnumeration import (
        EventAttendanceModeEnumeration,
    )
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.PostalAddress import PostalAddress
    from pydantic2_schemaorg.VirtualLocation import VirtualLocation
    from pydantic2_schemaorg.Review import Review
    from pydantic2_schemaorg.Schedule import Schedule
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.EventStatusType import EventStatusType
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.Offer import Offer
    from pydantic2_schemaorg.Grant import Grant



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class SpecialAnnouncement(CreativeWork):
    """A SpecialAnnouncement combines a simple date-stamped textual information update with contextualized
     Web links and other structured data. It represents an information update made by a locally-oriented organization,
     for example schools, pharmacies, healthcare providers, community groups, police, local government. For
     work in progress guidelines on Coronavirus-related markup see [this doc](https://docs.google.com/document/d/14ikaGCKxo50rRM7nvKSlbUpjyIk2WMQd3IkB1lItlrM/edit#).
     The motivating scenario for SpecialAnnouncement is the [Coronavirus pandemic](https://en.wikipedia.org/wiki/2019%E2%80%9320_coronavirus_pandemic),
     and the initial vocabulary is oriented to this urgent situation. Schema.org expect to improve the markup
     iteratively as it is deployed and as feedback emerges from use. In addition to our usual [Github entry](https://github.com/schemaorg/schemaorg/issues/2490),
     feedback comments can also be provided in [this document](https://docs.google.com/document/d/1fpdFFxk8s87CWwACs53SGkYv3aafSxz_DTtOQxMrBJQ/edit#).
     While this schema is designed to communicate urgent crisis-related information, it is not the same as an emergency
     warning technology like [CAP](https://en.wikipedia.org/wiki/Common_Alerting_Protocol), although
     there may be overlaps. The intent is to cover the kinds of everyday practical information being posted to existing
     websites during an emergency situation. Several kinds of information can be provided: We encourage the provision
     of \"name\", \"text\", \"datePosted\", \"expires\" (if appropriate), \"category\" and \"url\" as a simple
     baseline. It is important to provide a value for \"category\" where possible, most ideally as a well known
     URL from Wikipedia or Wikidata. In the case of the 2019-2020 Coronavirus pandemic, this should be \"https://en.wikipedia.org/w/index.php?title=2019-20_coronavirus_pandemic\"
     or \"https://www.wikidata.org/wiki/Q81068910\". For many of the possible properties, values can either
     be simple links or an inline description, depending on whether a summary is available. For a link, provide
     just the URL of the appropriate page as the property's value. For an inline description, use a [[WebContent]]
     type, and provide the url as a property of that, alongside at least a simple \"[[text]]\" summary of the page.
     It is unlikely that a single SpecialAnnouncement will need all of the possible properties simultaneously.
     We expect that in many cases the page referenced might contain more specialized structured data, e.g. contact
     info, [[openingHours]], [[Event]], [[FAQPage]] etc. By linking to those pages from a [[SpecialAnnouncement]]
     you can help make it clearer that the events are related to the situation (e.g. Coronavirus) indicated by the
     [[category]] property of the [[SpecialAnnouncement]]. Many [[SpecialAnnouncement]]s will relate to
     particular regions and to identifiable local organizations. Use [[spatialCoverage]] for the region, and
     [[announcementLocation]] to indicate specific [[LocalBusiness]]es and [[CivicStructure]]s. If the
     announcement affects both a particular region and a specific location (for example, a library closure that
     serves an entire region), use both [[spatialCoverage]] and [[announcementLocation]]. The [[about]] property
     can be used to indicate entities that are the focus of the announcement. We now recommend using [[about]] only
     for representing non-location entities (e.g. a [[Course]] or a [[RadioStation]]). For places, use [[announcementLocation]]
     and [[spatialCoverage]]. Consumers of this markup should be aware that the initial design encouraged the
     use of [[about]] for locations too. The basic content of [[SpecialAnnouncement]] is similar to that of an
     [RSS](https://en.wikipedia.org/wiki/RSS) or [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard))
     feed. For publishers without such feeds, basic feed-like information can be shared by posting [[SpecialAnnouncement]]
     updates in a page, e.g. using JSON-LD. For sites with Atom/RSS functionality, you can point to a feed with the
     [[webFeed]] property. This can be a simple URL, or an inline [[DataFeed]] object, with [[encodingFormat]]
     providing media type information, e.g. \"application/rss+xml\" or \"application/atom+xml\".

    See: https://schema.org/SpecialAnnouncement
    Model depth: 3
    """

    type_: str = Field(default="SpecialAnnouncement", alias="@type", const=True)
    diseasePreventionInfo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Information about disease prevention.",
    )
    quarantineGuidelines: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Guidelines about quarantine rules, e.g. in the context of a pandemic.",
    )
    category: Optional[
        Union[
            List[
                Union[
                    AnyUrl,
                    "URL",
                    str,
                    "Text",
                    "PhysicalActivityCategory",
                    "CategoryCode",
                    "Thing",
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "PhysicalActivityCategory",
            "CategoryCode",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.",
    )
    datePosted: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Publication date of an online listing.",
    )
    travelBans: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Information about travel bans, e.g. in the context of a pandemic.",
    )
    announcementLocation: Optional[
        Union[
            List[Union["CivicStructure", "LocalBusiness", str]],
            "CivicStructure",
            "LocalBusiness",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates a specific [[CivicStructure]] or [[LocalBusiness]] associated with the SpecialAnnouncement. For example, a specific testing facility or business with special opening hours. For a larger geographic region like a quarantine of an entire region, use [[spatialCoverage]].",
    )
    gettingTestedInfo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Information about getting tested (for a [[MedicalCondition]]), e.g. in the context of a pandemic.",
    )
    schoolClosuresInfo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Information about school closures.",
    )
    publicTransportClosuresInfo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Information about public transport closures.",
    )
    webFeed: Optional[
        Union[
            List[Union[AnyUrl, "URL", "DataFeed", str]], AnyUrl, "URL", "DataFeed", str
        ]
    ] = Field(
        default=None,
        description="The URL for a feed, e.g. associated with a podcast series, blog, or series of date-stamped updates. This is usually RSS or Atom.",
    )
    diseaseSpreadStatistics: Optional[
        Union[
            List[Union[AnyUrl, "URL", "Observation", "WebContent", "Dataset", str]],
            AnyUrl,
            "URL",
            "Observation",
            "WebContent",
            "Dataset",
            str,
        ]
    ] = Field(
        default=None,
        description="Statistical information about the spread of a disease, either as [[WebContent]], or described directly as a [[Dataset]], or the specific [[Observation]]s in the dataset. When a [[WebContent]] URL is provided, the page indicated might also contain more such markup.",
    )
    newsUpdatesAndGuidelines: Optional[
        Union[
            List[Union[AnyUrl, "URL", "WebContent", str]],
            AnyUrl,
            "URL",
            "WebContent",
            str,
        ]
    ] = Field(
        default=None,
        description="Indicates a page with news updates and guidelines. This could often be (but is not required to be) the main page containing [[SpecialAnnouncement]] markup on a site.",
    )
    governmentBenefitsInfo: Optional[
        Union[List[Union["GovernmentService", str]], "GovernmentService", str]
    ] = Field(
        default=None,
        description="governmentBenefitsInfo provides information about government benefits associated with a SpecialAnnouncement.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.WebContent import WebContent
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.CivicStructure import CivicStructure
    from pydantic2_schemaorg.LocalBusiness import LocalBusiness
    from pydantic2_schemaorg.DataFeed import DataFeed
    from pydantic2_schemaorg.Observation import Observation
    from pydantic2_schemaorg.Dataset import Dataset
    from pydantic2_schemaorg.GovernmentService import GovernmentService



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class AnatomicalSystem(MedicalEntity):
    """An anatomical system is a group of anatomical structures that work together to perform a certain task. Anatomical
     systems, such as organ systems, are one organizing principle of anatomy, and can include circulatory, digestive,
     endocrine, integumentary, immune, lymphatic, muscular, nervous, reproductive, respiratory, skeletal,
     urinary, vestibular, and other systems.

    See: https://schema.org/AnatomicalSystem
    Model depth: 3
    """

    type_: str = Field(default="AnatomicalSystem", alias="@type", const=True)
    relatedStructure: Optional[
        Union[List[Union["AnatomicalStructure", str]], "AnatomicalStructure", str]
    ] = Field(
        default=None,
        description="Related anatomical structure(s) that are not part of the system but relate or connect to it, such as vascular bundles associated with an organ system.",
    )
    associatedPathophysiology: Optional[
        Union[List[Union[str, "Text"]], str, "Text"]
    ] = Field(
        default=None,
        description="If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.",
    )
    comprisedOf: Optional[
        Union[
            List[Union["AnatomicalSystem", "AnatomicalStructure", str]],
            "AnatomicalSystem",
            "AnatomicalStructure",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifying something physically contained by something else. Typically used here for the underlying anatomical structures, such as organs, that comprise the anatomical system.",
    )
    relatedCondition: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="A medical condition associated with this anatomy.",
    )
    relatedTherapy: Optional[
        Union[List[Union["MedicalTherapy", str]], "MedicalTherapy", str]
    ] = Field(
        default=None,
        description="A medical therapy related to this anatomy.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class Report(Article):
    """A Report generated by governmental or non-governmental organization.

    See: https://schema.org/Report
    Model depth: 4
    """

    type_: str = Field(default="Report", alias="@type", const=True)
    reportNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The number or other unique designator assigned to a Report by the publishing organization.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalDocument import DigitalDocument


class NoteDigitalDocument(DigitalDocument):
    """A file containing a note, primarily for the author.

    See: https://schema.org/NoteDigitalDocument
    Model depth: 4
    """

    type_: str = Field(default="NoteDigitalDocument", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ItemAvailability import ItemAvailability


class LimitedAvailability(ItemAvailability):
    """Indicates that the item has limited availability.

    See: https://schema.org/LimitedAvailability
    Model depth: 5
    """

    type_: str = Field(default="LimitedAvailability", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Resort import Resort
from pydantic2_schemaorg.SportsActivityLocation import SportsActivityLocation


class SkiResort(Resort, SportsActivityLocation):
    """A ski resort.

    See: https://schema.org/SkiResort
    Model depth: 5
    """

    type_: str = Field(default="SkiResort", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime, time
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class OpeningHoursSpecification(StructuredValue):
    """A structured value providing information about the opening hours of a place or a certain service inside a place.
     The place is __open__ if the [[opens]] property is specified, and __closed__ otherwise. If the value for the
     [[closes]] property is less than the value for the [[opens]] property then the hour range is assumed to span
     over the next day.

    See: https://schema.org/OpeningHoursSpecification
    Model depth: 4
    """

    type_: str = Field(default="OpeningHoursSpecification", alias="@type", const=True)
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    opens: Optional[Union[List[Union[time, "Time", str]], time, "Time", str]] = Field(
        default=None,
        description="The opening hour of the place or service on the given day(s) of the week.",
    )
    dayOfWeek: Optional[Union[List[Union["DayOfWeek", str]], "DayOfWeek", str]] = Field(
        default=None,
        description="The day of the week for which these opening hours are valid.",
    )
    validThrough: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.",
    )
    closes: Optional[Union[List[Union[time, "Time", str]], time, "Time", str]] = Field(
        default=None,
        description="The closing hour of the place or service on the given day(s) of the week.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.DayOfWeek import DayOfWeek



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PlaceOfWorship import PlaceOfWorship


class HinduTemple(PlaceOfWorship):
    """A Hindu temple.

    See: https://schema.org/HinduTemple
    Model depth: 5
    """

    type_: str = Field(default="HinduTemple", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CivicStructure import CivicStructure
from pydantic2_schemaorg.Organization import Organization


class EducationalOrganization(CivicStructure, Organization):
    """An educational organization.

    See: https://schema.org/EducationalOrganization
    Model depth: 3
    """

    type_: str = Field(default="EducationalOrganization", alias="@type", const=True)
    alumni: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="Alumni of an organization.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AchieveAction import AchieveAction


class TieAction(AchieveAction):
    """The act of reaching a draw in a competitive activity.

    See: https://schema.org/TieAction
    Model depth: 4
    """

    type_: str = Field(default="TieAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Statement(CreativeWork):
    """A statement about something, for example a fun or interesting fact. If known, the main entity this statement
     is about can be indicated using mainEntity. For more formal claims (e.g. in Fact Checking), consider using
     [[Claim]] instead. Use the [[text]] property to capture the text of the statement.

    See: https://schema.org/Statement
    Model depth: 3
    """

    type_: str = Field(default="Statement", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialService import FinancialService


class AutomatedTeller(FinancialService):
    """ATM/cash machine.

    See: https://schema.org/AutomatedTeller
    Model depth: 5
    """

    type_: str = Field(default="AutomatedTeller", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class DrugCost(MedicalEntity):
    """The cost per unit of a medical drug. Note that this type is not meant to represent the price in an offer of a drug
     for sale; see the Offer type for that. This type will typically be used to tag wholesale or average retail cost
     of a drug, or maximum reimbursable cost. Costs of medical drugs vary widely depending on how and where they
     are paid for, so while this type captures some of the variables, costs should be used with caution by consumers
     of this schema's markup.

    See: https://schema.org/DrugCost
    Model depth: 3
    """

    type_: str = Field(default="DrugCost", alias="@type", const=True)
    drugUnit: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unit in which the drug is measured, e.g. '5 mg tablet'.",
    )
    applicableLocation: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The location in which the status applies.",
    )
    costOrigin: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Additional details to capture the origin of the cost data. For example, 'Medicare Part B'.",
    )
    costPerUnit: Optional[
        Union[
            List[
                Union[StrictInt, StrictFloat, "Number", str, "Text", "QualitativeValue"]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="The cost per unit of the drug.",
    )
    costCategory: Optional[
        Union[List[Union["DrugCostCategory", str]], "DrugCostCategory", str]
    ] = Field(
        default=None,
        description="The category of cost, such as wholesale, retail, reimbursement cap, etc.",
    )
    costCurrency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The currency (in 3-letter) of the drug cost. See: http://en.wikipedia.org/wiki/ISO_4217.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue
    from pydantic2_schemaorg.DrugCostCategory import DrugCostCategory



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ControlAction import ControlAction


class DeactivateAction(ControlAction):
    """The act of stopping or deactivating a device or application (e.g. stopping a timer or turning off a flashlight).

    See: https://schema.org/DeactivateAction
    Model depth: 4
    """

    type_: str = Field(default="DeactivateAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WearableSizeSystemEnumeration import (
    WearableSizeSystemEnumeration,
)


class WearableSizeSystemEN13402(WearableSizeSystemEnumeration):
    """EN 13402 (joint European standard for size labelling of clothes).

    See: https://schema.org/WearableSizeSystemEN13402
    Model depth: 6
    """

    type_: str = Field(default="WearableSizeSystemEN13402", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPage import WebPage


class ContactPage(WebPage):
    """Web page type: Contact page.

    See: https://schema.org/ContactPage
    Model depth: 4
    """

    type_: str = Field(default="ContactPage", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.QuantitativeValueDistribution import (
    QuantitativeValueDistribution,
)


class MonetaryAmountDistribution(QuantitativeValueDistribution):
    """A statistical distribution of monetary amounts.

    See: https://schema.org/MonetaryAmountDistribution
    Model depth: 5
    """

    type_: str = Field(default="MonetaryAmountDistribution", alias="@type", const=True)
    currency: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The currency in which the monetary amount is expressed. Use standard formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class SportsOrganization(Organization):
    """Represents the collection of all sports organizations, including sports teams, governing bodies, and sports
     associations.

    See: https://schema.org/SportsOrganization
    Model depth: 3
    """

    type_: str = Field(default="SportsOrganization", alias="@type", const=True)
    sport: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="A type of sport (e.g. Baseball).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class EnergyEfficiencyEnumeration(Enumeration):
    """Enumerates energy efficiency levels (also known as \"classes\" or \"ratings\") and certifications that
     are part of several international energy efficiency standards.

    See: https://schema.org/EnergyEfficiencyEnumeration
    Model depth: 4
    """

    type_: str = Field(default="EnergyEfficiencyEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class Bone(AnatomicalStructure):
    """Rigid connective tissue that comprises up the skeletal structure of the human body.

    See: https://schema.org/Bone
    Model depth: 4
    """

    type_: str = Field(default="Bone", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class ReturnMethodEnumeration(Enumeration):
    """Enumerates several types of product return methods.

    See: https://schema.org/ReturnMethodEnumeration
    Model depth: 4
    """

    type_: str = Field(default="ReturnMethodEnumeration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CarUsageType import CarUsageType


class TaxiVehicleUsage(CarUsageType):
    """Indicates the usage of the car as a taxi.

    See: https://schema.org/TaxiVehicleUsage
    Model depth: 5
    """

    type_: str = Field(default="TaxiVehicleUsage", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.NLNonprofitType import NLNonprofitType


class NonprofitSBBI(NLNonprofitType):
    """NonprofitSBBI: Non-profit type referring to a Social Interest Promoting Institution (NL).

    See: https://schema.org/NonprofitSBBI
    Model depth: 6
    """

    type_: str = Field(default="NonprofitSBBI", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class DangerousGoodConsideration(AdultOrientedEnumeration):
    """The item is dangerous and requires careful handling and/or special training of the user. See also the [UN Model
     Classification](https://unece.org/DAM/trans/danger/publi/unrec/rev17/English/02EREv17_Part2.pdf)
     defining the 9 classes of dangerous goods such as explosives, gases, flammables, and more.

    See: https://schema.org/DangerousGoodConsideration
    Model depth: 5
    """

    type_: str = Field(default="DangerousGoodConsideration", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.HowToItem import HowToItem


class HowToSupply(HowToItem):
    """A supply consumed when performing the instructions for how to achieve a result.

    See: https://schema.org/HowToSupply
    Model depth: 5
    """

    type_: str = Field(default="HowToSupply", alias="@type", const=True)
    estimatedCost: Optional[
        Union[List[Union[str, "Text", "MonetaryAmount"]], str, "Text", "MonetaryAmount"]
    ] = Field(
        default=None,
        description="The estimated cost of the supply or supplies consumed when performing instructions.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OfferItemCondition import OfferItemCondition


class NewCondition(OfferItemCondition):
    """Indicates that the item is new.

    See: https://schema.org/NewCondition
    Model depth: 5
    """

    type_: str = Field(default="NewCondition", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.LoanOrCredit import LoanOrCredit


class MortgageLoan(LoanOrCredit):
    """A loan in which property or real estate is used as collateral. (A loan securitized against some real estate.)

    See: https://schema.org/MortgageLoan
    Model depth: 6
    """

    type_: str = Field(default="MortgageLoan", alias="@type", const=True)
    loanMortgageMandateAmount: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="Amount of mortgage mandate that can be converted into a proper mortgage at a later stage.",
    )
    domiciledMortgage: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Whether borrower is a resident of the jurisdiction where the property is located.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.Boolean import Boolean



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialService import FinancialService


class AccountingService(FinancialService):
    """Accountancy business. As a [[LocalBusiness]] it can be described as a [[provider]] of one or more [[Service]](s).

    See: https://schema.org/AccountingService
    Model depth: 5
    """

    type_: str = Field(default="AccountingService", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class PropertyValue(StructuredValue):
    """A property-value pair, e.g. representing a feature of a product or place. Use the 'name' property for the name
     of the property. If there is an additional human-readable version of the value, put that into the 'description'
     property. Always use specific schema.org properties when a) they exist and b) you can populate them. Using
     PropertyValue as a substitute will typically not trigger the same effect as using the original, specific
     property.

    See: https://schema.org/PropertyValue
    Model depth: 4
    """

    type_: str = Field(default="PropertyValue", alias="@type", const=True)
    valueReference: Optional[
        Union[
            List[
                Union[
                    str,
                    "Text",
                    "QualitativeValue",
                    "PropertyValue",
                    "Enumeration",
                    "QuantitativeValue",
                    "DefinedTerm",
                    "StructuredValue",
                    "MeasurementTypeEnumeration",
                ]
            ],
            str,
            "Text",
            "QualitativeValue",
            "PropertyValue",
            "Enumeration",
            "QuantitativeValue",
            "DefinedTerm",
            "StructuredValue",
            "MeasurementTypeEnumeration",
        ]
    ] = Field(
        default=None,
        description="A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.",
    )
    measurementTechnique: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description='A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable. The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery. For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory". If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMetholdEnumeration]].',
    )
    unitCode: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.",
    )
    propertyID: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="A commonly used identifier for the characteristic represented by the property, e.g. a manufacturer or a standard code for a property. propertyID can be (1) a prefixed string, mainly meant to be used with standards for product properties; (2) a site-specific, non-prefixed string (e.g. the primary key of the property or the vendor-specific ID of the property), or (3) a URL indicating the type of the property, either pointing to an external vocabulary, or a Web resource that describes the property (e.g. a glossary entry). Standards bodies should promote a standard prefix for the identifiers of properties from their standards.",
    )
    maxValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The upper value of some characteristic or property.",
    )
    value: Optional[
        Union[
            List[
                Union[
                    StrictInt,
                    StrictFloat,
                    "Number",
                    StrictBool,
                    "Boolean",
                    str,
                    "Text",
                    "StructuredValue",
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            StrictBool,
            "Boolean",
            str,
            "Text",
            "StructuredValue",
        ]
    ] = Field(
        default=None,
        description="The value of a [[QuantitativeValue]] (including [[Observation]]) or property value node. * For [[QuantitativeValue]] and [[MonetaryAmount]], the recommended type for values is 'Number'. * For [[PropertyValue]], it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'. * Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols. * Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.",
    )
    minValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The lower value of some characteristic or property.",
    )
    unitText: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for <a href='unitCode'>unitCode</a>.",
    )
    measurementMethod: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue
    from pydantic2_schemaorg.Enumeration import Enumeration
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.StructuredValue import StructuredValue
    from pydantic2_schemaorg.MeasurementTypeEnumeration import (
        MeasurementTypeEnumeration,
    )
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.MeasurementMethodEnum import MeasurementMethodEnum
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Boolean import Boolean



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalAudience import MedicalAudience
from pydantic2_schemaorg.Person import Person


class Patient(MedicalAudience, Person):
    """A patient is any person recipient of health care services.

    See: https://schema.org/Patient
    Model depth: 3
    """

    type_: str = Field(default="Patient", alias="@type", const=True)
    diagnosis: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="One or more alternative conditions considered in the differential diagnosis process as output of a diagnosis process.",
    )
    healthCondition: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="Specifying the health condition(s) of a patient, medical study, or other target audience.",
    )
    drug: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Specifying a drug or medicine used in a medication procedure.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.Drug import Drug



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Store import Store


class MovieRentalStore(Store):
    """A movie rental store.

    See: https://schema.org/MovieRentalStore
    Model depth: 5
    """

    type_: str = Field(default="MovieRentalStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Residence import Residence


class GatedResidenceCommunity(Residence):
    """Residence type: Gated community.

    See: https://schema.org/GatedResidenceCommunity
    Model depth: 4
    """

    type_: str = Field(default="GatedResidenceCommunity", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Store import Store


class PawnShop(Store):
    """A shop that will buy, or lend money against the security of, personal possessions.

    See: https://schema.org/PawnShop
    Model depth: 5
    """

    type_: str = Field(default="PawnShop", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaGallery import MediaGallery


class ImageGallery(MediaGallery):
    """Web page type: Image gallery page.

    See: https://schema.org/ImageGallery
    Model depth: 6
    """

    type_: str = Field(default="ImageGallery", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CarUsageType import CarUsageType


class DrivingSchoolVehicleUsage(CarUsageType):
    """Indicates the usage of the vehicle for driving school.

    See: https://schema.org/DrivingSchoolVehicleUsage
    Model depth: 5
    """

    type_: str = Field(default="DrivingSchoolVehicleUsage", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DoseSchedule import DoseSchedule


class ReportedDoseSchedule(DoseSchedule):
    """A patient-reported or observed dosing schedule for a drug or supplement.

    See: https://schema.org/ReportedDoseSchedule
    Model depth: 5
    """

    type_: str = Field(default="ReportedDoseSchedule", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class MusicComposition(CreativeWork):
    """A musical composition.

    See: https://schema.org/MusicComposition
    Model depth: 3
    """

    type_: str = Field(default="MusicComposition", alias="@type", const=True)
    composer: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The person or organization who wrote a composition, or who is the composer of a work performed at some event.",
    )
    musicArrangement: Optional[
        Union[List[Union["MusicComposition", str]], "MusicComposition", str]
    ] = Field(
        default=None,
        description="An arrangement derived from the composition.",
    )
    musicCompositionForm: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The type of composition (e.g. overture, sonata, symphony, etc.).",
        )
    )
    firstPerformance: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="The date and place the work was first performed.",
    )
    musicalKey: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The key, mode, or scale this composition uses.",
    )
    recordedAs: Optional[
        Union[List[Union["MusicRecording", str]], "MusicRecording", str]
    ] = Field(
        default=None,
        description="An audio recording of the work.",
    )
    lyrics: Optional[Union[List[Union["CreativeWork", str]], "CreativeWork", str]] = (
        Field(
            default=None,
            description="The words in the song.",
        )
    )
    includedComposition: Optional[
        Union[List[Union["MusicComposition", str]], "MusicComposition", str]
    ] = Field(
        default=None,
        description="Smaller compositions included in this work (e.g. a movement in a symphony).",
    )
    iswcCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard Musical Work Code for the composition.",
    )
    lyricist: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The person who wrote the words.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.MusicRecording import MusicRecording
    from pydantic2_schemaorg.CreativeWork import CreativeWork



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LodgingBusiness import LodgingBusiness


class Hotel(LodgingBusiness):
    """A hotel is an establishment that provides lodging paid on a short-term basis (source: Wikipedia, the free
     encyclopedia, see http://en.wikipedia.org/wiki/Hotel). <br /><br /> See also the <a href=\"/docs/hotels.html\">dedicated
     document on the use of schema.org for marking up hotels and other forms of accommodations</a>.

    See: https://schema.org/Hotel
    Model depth: 5
    """

    type_: str = Field(default="Hotel", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DayOfWeek import DayOfWeek


class Thursday(DayOfWeek):
    """The day of the week between Wednesday and Friday.

    See: https://schema.org/Thursday
    Model depth: 5
    """

    type_: str = Field(default="Thursday", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Place import Place


class LandmarksOrHistoricalBuildings(Place):
    """An historical landmark or building.

    See: https://schema.org/LandmarksOrHistoricalBuildings
    Model depth: 3
    """

    type_: str = Field(
        default="LandmarksOrHistoricalBuildings", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Episode import Episode


class PodcastEpisode(Episode):
    """A single episode of a podcast series.

    See: https://schema.org/PodcastEpisode
    Model depth: 4
    """

    type_: str = Field(default="PodcastEpisode", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalDevicePurpose import MedicalDevicePurpose


class Therapeutic(MedicalDevicePurpose):
    """A medical device used for therapeutic purposes.

    See: https://schema.org/Therapeutic
    Model depth: 6
    """

    type_: str = Field(default="Therapeutic", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.Substance import Substance
from pydantic2_schemaorg.Product import Product


class DietarySupplement(Substance, Product):
    """A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients
     may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes,
     organ tissues, glandulars and metabolites.

    See: https://schema.org/DietarySupplement
    Model depth: 3
    """

    type_: str = Field(default="DietarySupplement", alias="@type", const=True)
    proprietaryName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Proprietary name given to the diet plan, typically by its originator or creator.",
    )
    recommendedIntake: Optional[
        Union[
            List[Union["RecommendedDoseSchedule", str]], "RecommendedDoseSchedule", str
        ]
    ] = Field(
        default=None,
        description="Recommended intake of this supplement for a given population as defined by a specific recommending authority.",
    )
    safetyConsideration: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Any potential safety concern associated with the supplement. May include interactions with other drugs and foods, pregnancy, breastfeeding, known adverse reactions, and documented efficacy of the supplement.",
    )
    nonProprietaryName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The generic name of this drug or supplement.",
    )
    maximumIntake: Optional[
        Union[List[Union["MaximumDoseSchedule", str]], "MaximumDoseSchedule", str]
    ] = Field(
        default=None,
        description="Recommended intake of this supplement for a given population as defined by a specific recommending authority.",
    )
    legalStatus: Optional[
        Union[
            List[Union[str, "Text", "DrugLegalStatus", "MedicalEnumeration"]],
            str,
            "Text",
            "DrugLegalStatus",
            "MedicalEnumeration",
        ]
    ] = Field(
        default=None,
        description="The drug or supplement's legal status, including any controlled substance schedules that apply.",
    )
    activeIngredient: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An active ingredient, typically chemical compounds and/or biologic substances.",
    )
    mechanismOfAction: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.",
    )
    isProprietary: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="True if this item's name is a proprietary/brand name (vs. generic name).",
    )
    targetPopulation: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.RecommendedDoseSchedule import RecommendedDoseSchedule
    from pydantic2_schemaorg.MaximumDoseSchedule import MaximumDoseSchedule
    from pydantic2_schemaorg.DrugLegalStatus import DrugLegalStatus
    from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration
    from pydantic2_schemaorg.Boolean import Boolean



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PublicationEvent import PublicationEvent


class OnDemandEvent(PublicationEvent):
    """A publication event, e.g. catch-up TV or radio podcast, during which a program is available on-demand.

    See: https://schema.org/OnDemandEvent
    Model depth: 4
    """

    type_: str = Field(default="OnDemandEvent", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentStatusType import PaymentStatusType


class PaymentDeclined(PaymentStatusType):
    """The payee received the payment, but it was declined for some reason.

    See: https://schema.org/PaymentDeclined
    Model depth: 6
    """

    type_: str = Field(default="PaymentDeclined", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SportsActivityLocation import SportsActivityLocation
from pydantic2_schemaorg.HealthAndBeautyBusiness import HealthAndBeautyBusiness


class HealthClub(SportsActivityLocation, HealthAndBeautyBusiness):
    """A health club.

    See: https://schema.org/HealthClub
    Model depth: 5
    """

    type_: str = Field(default="HealthClub", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Toxicologic(MedicalSpecialty):
    """A specific branch of medical science that is concerned with poisons, their nature, effects and detection
     and involved in the treatment of poisoning.

    See: https://schema.org/Toxicologic
    Model depth: 6
    """

    type_: str = Field(default="Toxicologic", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EventAttendanceModeEnumeration import (
    EventAttendanceModeEnumeration,
)


class OfflineEventAttendanceMode(EventAttendanceModeEnumeration):
    """OfflineEventAttendanceMode - an event that is primarily conducted offline.

    See: https://schema.org/OfflineEventAttendanceMode
    Model depth: 5
    """

    type_: str = Field(default="OfflineEventAttendanceMode", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class PriceComponentTypeEnumeration(Enumeration):
    """Enumerates different price components that together make up the total price for an offered product.

    See: https://schema.org/PriceComponentTypeEnumeration
    Model depth: 4
    """

    type_: str = Field(
        default="PriceComponentTypeEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentMethodType import PaymentMethodType


class CheckInAdvance(PaymentMethodType):
    """Payment in advance by sending a check, equivalent to <code>http://purl.org/goodrelations/v1#CheckInAdvance</code>.

    See: https://schema.org/CheckInAdvance
    Model depth: 5
    """

    type_: str = Field(default="CheckInAdvance", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod


class ParcelService(DeliveryMethod):
    """A private parcel service as the delivery mode available for a certain offer. Commonly used values: * http://purl.org/goodrelations/v1#DHL
     * http://purl.org/goodrelations/v1#FederalExpress * http://purl.org/goodrelations/v1#UPS

    See: https://schema.org/ParcelService
    Model depth: 5
    """

    type_: str = Field(default="ParcelService", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Guide(CreativeWork):
    """[[Guide]] is a page or article that recommends specific products or services, or aspects of a thing for a user
     to consider. A [[Guide]] may represent a Buying Guide and detail aspects of products or services for a user
     to consider. A [[Guide]] may represent a Product Guide and recommend specific products or services. A [[Guide]]
     may represent a Ranked List and recommend specific products or services with ranking.

    See: https://schema.org/Guide
    Model depth: 3
    """

    type_: str = Field(default="Guide", alias="@type", const=True)
    reviewAspect: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="This Review or Rating is relevant to this part or facet of the itemReviewed.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AudioObject import AudioObject


class AudioObjectSnapshot(AudioObject):
    """A specific and exact (byte-for-byte) version of an [[AudioObject]]. Two byte-for-byte identical files,
     for the purposes of this type, considered identical. If they have different embedded metadata the files will
     differ. Different external facts about the files, e.g. creator or dateCreated that aren't represented in
     their actual content, do not affect this notion of identity.

    See: https://schema.org/AudioObjectSnapshot
    Model depth: 5
    """

    type_: str = Field(default="AudioObjectSnapshot", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class HealthcareConsideration(AdultOrientedEnumeration):
    """Item is a pharmaceutical (e.g., a prescription or OTC drug) or a restricted medical device.

    See: https://schema.org/HealthcareConsideration
    Model depth: 5
    """

    type_: str = Field(default="HealthcareConsideration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalProcedure import MedicalProcedure


class SurgicalProcedure(MedicalProcedure):
    """A medical procedure involving an incision with instruments; performed for diagnose, or therapeutic purposes.

    See: https://schema.org/SurgicalProcedure
    Model depth: 4
    """

    type_: str = Field(default="SurgicalProcedure", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTest import MedicalTest


class MedicalTestPanel(MedicalTest):
    """Any collection of tests commonly ordered together.

    See: https://schema.org/MedicalTestPanel
    Model depth: 4
    """

    type_: str = Field(default="MedicalTestPanel", alias="@type", const=True)
    subTest: Optional[Union[List[Union["MedicalTest", str]], "MedicalTest", str]] = (
        Field(
            default=None,
            description="A component test of the panel.",
        )
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalTest import MedicalTest



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Vehicle import Vehicle


class Motorcycle(Vehicle):
    """A motorcycle or motorbike is a single-track, two-wheeled motor vehicle.

    See: https://schema.org/Motorcycle
    Model depth: 4
    """

    type_: str = Field(default="Motorcycle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class AssessAction(Action):
    """The act of forming one's opinion, reaction or sentiment.

    See: https://schema.org/AssessAction
    Model depth: 3
    """

    type_: str = Field(default="AssessAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType


class LiveAlbum(MusicAlbumProductionType):
    """LiveAlbum.

    See: https://schema.org/LiveAlbum
    Model depth: 5
    """

    type_: str = Field(default="LiveAlbum", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Clip import Clip


class VideoGameClip(Clip):
    """A short segment/part of a video game.

    See: https://schema.org/VideoGameClip
    Model depth: 4
    """

    type_: str = Field(default="VideoGameClip", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class CommunityHealth(MedicalSpecialty, MedicalBusiness):
    """A field of public health focusing on improving health characteristics of a defined population in relation
     with their geographical or environment areas.

    See: https://schema.org/CommunityHealth
    Model depth: 5
    """

    type_: str = Field(default="CommunityHealth", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.AssessAction import AssessAction


class ReviewAction(AssessAction):
    """The act of producing a balanced opinion about the object for an audience. An agent reviews an object with participants
     resulting in a review.

    See: https://schema.org/ReviewAction
    Model depth: 4
    """

    type_: str = Field(default="ReviewAction", alias="@type", const=True)
    resultReview: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="A sub property of result. The review that resulted in the performing of the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Review import Review



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class VisualArtwork(CreativeWork):
    """A work of art that is primarily visual in character.

    See: https://schema.org/VisualArtwork
    Model depth: 3
    """

    type_: str = Field(default="VisualArtwork", alias="@type", const=True)
    artEdition: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description="The number of copies when multiple copies of a piece of artwork are produced - e.g. for a limited edition of 20 prints, 'artEdition' refers to the total number of copies (in this example \"20\").",
    )
    artist: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.",
    )
    artform: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="e.g. Painting, Drawing, Sculpture, Print, Photograph, Assemblage, Collage, etc.",
    )
    inker: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who traces over the pencil drawings in ink after pencils are complete.",
    )
    artworkSurface: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The supporting materials for the artwork, e.g. Canvas, Paper, Wood, Board, etc.",
    )
    letterer: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who adds lettering, including speech balloons and sound effects, to artwork.",
    )
    width: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The width of the item.",
    )
    surface: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="A material used as a surface in some artwork, e.g. Canvas, Paper, Wood, Board, etc.",
    )
    colorist: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who adds color to inked drawings.",
    )
    penciler: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who draws the primary narrative artwork.",
    )
    artMedium: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="The material used. (E.g. Oil, Watercolour, Acrylic, Linoprint, Marble, Cyanotype, Digital, Lithograph, DryPoint, Intaglio, Pastel, Woodcut, Pencil, Mixed Media, etc.)",
    )
    height: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The height of the item.",
    )
    depth: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The depth of the item.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Distance import Distance
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Audience(Intangible):
    """Intended audience for an item, i.e. the group for whom the item was created.

    See: https://schema.org/Audience
    Model depth: 3
    """

    type_: str = Field(default="Audience", alias="@type", const=True)
    geographicArea: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The geographic area associated with the audience.",
    )
    audienceType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The target group associated with a given audience (e.g. veterans, car owners, musicians, etc.).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalProcedureType import MedicalProcedureType


class NoninvasiveProcedure(MedicalProcedureType):
    """A type of medical procedure that involves noninvasive techniques.

    See: https://schema.org/NoninvasiveProcedure
    Model depth: 6
    """

    type_: str = Field(default="NoninvasiveProcedure", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class CertificationStatusEnumeration(Enumeration):
    """Enumerates the different statuses of a Certification (Active and Inactive).

    See: https://schema.org/CertificationStatusEnumeration
    Model depth: 4
    """

    type_: str = Field(
        default="CertificationStatusEnumeration", alias="@type", const=True
    )



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PropertyValue import PropertyValue


class LocationFeatureSpecification(PropertyValue):
    """Specifies a location feature by providing a structured value representing a feature of an accommodation
     as a property-value pair of varying degrees of formality.

    See: https://schema.org/LocationFeatureSpecification
    Model depth: 5
    """

    type_: str = Field(
        default="LocationFeatureSpecification", alias="@type", const=True
    )
    validFrom: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date when the item becomes valid.",
    )
    hoursAvailable: Optional[
        Union[
            List[Union["OpeningHoursSpecification", str]],
            "OpeningHoursSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The hours during which this service or contact is available.",
    )
    validThrough: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.OpeningHoursSpecification import OpeningHoursSpecification



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration


class CausesHealthAspect(HealthAspectEnumeration):
    """Information about the causes and main actions that gave rise to the topic.

    See: https://schema.org/CausesHealthAspect
    Model depth: 5
    """

    type_: str = Field(default="CausesHealthAspect", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Audience import Audience


class BusinessAudience(Audience):
    """A set of characteristics belonging to businesses, e.g. who compose an item's target audience.

    See: https://schema.org/BusinessAudience
    Model depth: 4
    """

    type_: str = Field(default="BusinessAudience", alias="@type", const=True)
    numberOfEmployees: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The number of employees in an organization, e.g. business.",
    )
    yearlyRevenue: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The size of the business in annual revenue.",
    )
    yearsInOperation: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The age of the business.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicAlbumReleaseType import MusicAlbumReleaseType


class BroadcastRelease(MusicAlbumReleaseType):
    """BroadcastRelease.

    See: https://schema.org/BroadcastRelease
    Model depth: 5
    """

    type_: str = Field(default="BroadcastRelease", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyOfWater import BodyOfWater


class RiverBodyOfWater(BodyOfWater):
    """A river (for example, the broad majestic Shannon).

    See: https://schema.org/RiverBodyOfWater
    Model depth: 5
    """

    type_: str = Field(default="RiverBodyOfWater", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BookFormatType import BookFormatType


class Paperback(BookFormatType):
    """Book format: Paperback.

    See: https://schema.org/Paperback
    Model depth: 5
    """

    type_: str = Field(default="Paperback", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel


class EvidenceLevelC(MedicalEvidenceLevel):
    """Only consensus opinion of experts, case studies, or standard-of-care.

    See: https://schema.org/EvidenceLevelC
    Model depth: 6
    """

    type_: str = Field(default="EvidenceLevelC", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Pathology(MedicalSpecialty):
    """A specific branch of medical science that is concerned with the study of the cause, origin and nature of a disease
     state, including its consequences as a result of manifestation of the disease. In clinical care, the term
     is used to designate a branch of medicine using laboratory tests to diagnose and determine the prognostic
     significance of illness.

    See: https://schema.org/Pathology
    Model depth: 6
    """

    type_: str = Field(default="Pathology", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date
from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Thing import Thing


class Person(Thing):
    """A person (alive, dead, undead, or fictional).

    See: https://schema.org/Person
    Model depth: 2
    """

    type_: str = Field(default="Person", alias="@type", const=True)
    deathDate: Optional[Union[List[Union[date, "Date", str]], date, "Date", str]] = (
        Field(
            default=None,
            description="Date of death.",
        )
    )
    taxID: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US or the CIF/NIF in Spain.",
    )
    honorificPrefix: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An honorific prefix preceding a Person's name such as Dr/Mrs/Mr.",
    )
    interactionStatistic: Optional[
        Union[List[Union["InteractionCounter", str]], "InteractionCounter", str]
    ] = Field(
        default=None,
        description="The number of interactions for the CreativeWork using the WebSite or SoftwareApplication. The most specific child type of InteractionCounter should be used.",
    )
    worksFor: Optional[Union[List[Union["Organization", str]], "Organization", str]] = (
        Field(
            default=None,
            description="Organizations that the person works for.",
        )
    )
    jobTitle: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The job title of the person (for example, Financial Manager).",
    )
    knowsAbout: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "Thing"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "Thing",
        ]
    ] = Field(
        default=None,
        description="Of a [[Person]], and less typically of an [[Organization]], to indicate a topic that is known about - suggesting possible expertise but not implying it. We do not distinguish skill levels here, or relate this to educational content, events, objectives or [[JobPosting]] descriptions.",
    )
    nationality: Optional[Union[List[Union["Country", str]], "Country", str]] = Field(
        default=None,
        description="Nationality of the person.",
    )
    funder: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports (sponsors) something through some kind of financial contribution.",
    )
    contactPoints: Optional[
        Union[List[Union["ContactPoint", str]], "ContactPoint", str]
    ] = Field(
        default=None,
        description="A contact point for a person or organization.",
    )
    memberOf: Optional[
        Union[
            List[Union["ProgramMembership", "MemberProgramTier", "Organization", str]],
            "ProgramMembership",
            "MemberProgramTier",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="An Organization (or ProgramMembership) to which this Person or Organization belongs.",
    )
    siblings: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A sibling of the person.",
    )
    weight: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The weight of the product or person.",
    )
    faxNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The fax number.",
    )
    owns: Optional[
        Union[
            List[Union["OwnershipInfo", "Product", str]],
            "OwnershipInfo",
            "Product",
            str,
        ]
    ] = Field(
        default=None,
        description="Products owned by the organization or person.",
    )
    hasCredential: Optional[
        Union[
            List[Union["EducationalOccupationalCredential", str]],
            "EducationalOccupationalCredential",
            str,
        ]
    ] = Field(
        default=None,
        description="A credential awarded to the Person or Organization.",
    )
    givenName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Given name. In the U.S., the first name of a Person.",
    )
    birthDate: Optional[Union[List[Union[date, "Date", str]], date, "Date", str]] = (
        Field(
            default=None,
            description="Date of birth.",
        )
    )
    seeks: Optional[Union[List[Union["Demand", str]], "Demand", str]] = Field(
        default=None,
        description="A pointer to products or services sought by the organization or person (demand).",
    )
    netWorth: Optional[
        Union[
            List[Union["MonetaryAmount", "PriceSpecification", str]],
            "MonetaryAmount",
            "PriceSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="The total financial value of the person as calculated by subtracting assets from liabilities.",
    )
    hasCertification: Optional[
        Union[List[Union["Certification", str]], "Certification", str]
    ] = Field(
        default=None,
        description="Certification information about a product, organization, service, place, or person.",
    )
    hasOccupation: Optional[
        Union[List[Union["Occupation", str]], "Occupation", str]
    ] = Field(
        default=None,
        description="The Person's occupation. For past professions, use Role for expressing dates.",
    )
    familyName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Family name. In the U.S., the last name of a Person.",
    )
    relatedTo: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The most generic familial relation.",
    )
    follows: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The most generic uni-directional social relation.",
    )
    alumniOf: Optional[
        Union[
            List[Union["EducationalOrganization", "Organization", str]],
            "EducationalOrganization",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="An organization that the person is an alumni of.",
    )
    deathPlace: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The place where the person died.",
    )
    knowsLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="Of a [[Person]], and less typically of an [[Organization]], to indicate a known language. We do not distinguish skill levels or reading/writing/speaking/signing here. Use language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47).",
    )
    affiliation: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="An organization that this person is affiliated with. For example, a school/university, a club, or a team.",
    )
    vatID: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Value-added Tax ID of the organization or person.",
    )
    brand: Optional[
        Union[List[Union["Brand", "Organization", str]], "Brand", "Organization", str]
    ] = Field(
        default=None,
        description="The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.",
    )
    agentInteractionStatistic: Optional[
        Union[List[Union["InteractionCounter", str]], "InteractionCounter", str]
    ] = Field(
        default=None,
        description="The number of completed interactions for this entity, in a particular role (the 'agent'), in a particular action (indicated in the statistic), and in a particular context (i.e. interactionService).",
    )
    makesOffer: Optional[Union[List[Union["Offer", str]], "Offer", str]] = Field(
        default=None,
        description="A pointer to products or services offered by the organization or person.",
    )
    isicV4: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.",
    )
    email: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Email address.",
    )
    globalLocationNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The [Global Location Number](http://www.gs1.org/gln) (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.",
        )
    )
    contactPoint: Optional[
        Union[List[Union["ContactPoint", str]], "ContactPoint", str]
    ] = Field(
        default=None,
        description="A contact point for a person or organization.",
    )
    performerIn: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="Event that this person is a performer or participant in.",
    )
    publishingPrinciples: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="The publishingPrinciples property indicates (typically via [[URL]]) a document describing the editorial principles of an [[Organization]] (or individual, e.g. a [[Person]] writing a blog) that relate to their activities as a publisher, e.g. ethics or diversity policies. When applied to a [[CreativeWork]] (e.g. [[NewsArticle]]) the principles are those of the party primarily responsible for the creation of the [[CreativeWork]]. While such policies are most typically expressed in natural language, sometimes related information (e.g. indicating a [[funder]]) can be expressed using schema.org terminology.",
    )
    hasOfferCatalog: Optional[
        Union[List[Union["OfferCatalog", str]], "OfferCatalog", str]
    ] = Field(
        default=None,
        description="Indicates an OfferCatalog listing for this Organization, Person, or Service.",
    )
    award: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An award won by or for this item.",
    )
    callSign: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A [callsign](https://en.wikipedia.org/wiki/Call_sign), as used in broadcasting and radio communications to identify people, radio and TV stations, or vehicles.",
    )
    sponsor: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.",
    )
    knows: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The most generic bi-directional social/work relation.",
    )
    homeLocation: Optional[
        Union[List[Union["Place", "ContactPoint", str]], "Place", "ContactPoint", str]
    ] = Field(
        default=None,
        description="A contact location for a person's residence.",
    )
    duns: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The Dun & Bradstreet DUNS number for identifying an organization or business person.",
    )
    birthPlace: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="The place where the person was born.",
    )
    awards: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Awards won by or for this item.",
    )
    workLocation: Optional[
        Union[List[Union["Place", "ContactPoint", str]], "Place", "ContactPoint", str]
    ] = Field(
        default=None,
        description="A contact location for a person's place of work.",
    )
    parents: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A parents of the person.",
    )
    children: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A child of the person.",
    )
    parent: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A parent of this person.",
    )
    naics: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The North American Industry Classification System (NAICS) code for a particular organization or business person.",
    )
    gender: Optional[
        Union[List[Union[str, "Text", "GenderType"]], str, "Text", "GenderType"]
    ] = Field(
        default=None,
        description='Gender of something, typically a [[Person]], but possibly also fictional characters, animals, etc. While https://schema.org/Male and https://schema.org/Female may be used, text strings are also acceptable for people who do not identify as a binary gender. The [[gender]] property can also be used in an extended sense to cover e.g. the gender of sports teams. As with the gender of individuals, we do not try to enumerate all possibilities. A mixed-gender [[SportsTeam]] can be indicated with a text value of "Mixed".',
    )
    hasPOS: Optional[Union[List[Union["Place", str]], "Place", str]] = Field(
        default=None,
        description="Points-of-Sales operated by the organization or person.",
    )
    sibling: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A sibling of the person.",
    )
    spouse: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The person's spouse.",
    )
    colleague: Optional[
        Union[List[Union[AnyUrl, "URL", "Person", str]], AnyUrl, "URL", "Person", str]
    ] = Field(
        default=None,
        description="A colleague of the person.",
    )
    honorificSuffix: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An honorific suffix following a Person's name such as M.D./PhD/MSCSW.",
    )
    height: Optional[
        Union[
            List[Union["Distance", "QuantitativeValue", str]],
            "Distance",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The height of the item.",
    )
    funding: Optional[Union[List[Union["Grant", str]], "Grant", str]] = Field(
        default=None,
        description="A [[Grant]] that directly or indirectly provide funding or sponsorship for this item. See also [[ownershipFundingInfo]].",
    )
    telephone: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The telephone number.",
    )
    address: Optional[
        Union[List[Union[str, "Text", "PostalAddress"]], str, "Text", "PostalAddress"]
    ] = Field(
        default=None,
        description="Physical address of the item.",
    )
    additionalName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An additional name for a Person, can be used for a middle name.",
    )
    colleagues: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A colleague of the person.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.InteractionCounter import InteractionCounter
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Thing import Thing
    from pydantic2_schemaorg.Country import Country
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.ProgramMembership import ProgramMembership
    from pydantic2_schemaorg.MemberProgramTier import MemberProgramTier
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.OwnershipInfo import OwnershipInfo
    from pydantic2_schemaorg.Product import Product
    from pydantic2_schemaorg.EducationalOccupationalCredential import (
        EducationalOccupationalCredential,
    )
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.PriceSpecification import PriceSpecification
    from pydantic2_schemaorg.Certification import Certification
    from pydantic2_schemaorg.Occupation import Occupation
    from pydantic2_schemaorg.EducationalOrganization import EducationalOrganization
    from pydantic2_schemaorg.Place import Place
    from pydantic2_schemaorg.Language import Language
    from pydantic2_schemaorg.Brand import Brand
    from pydantic2_schemaorg.Offer import Offer
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.OfferCatalog import OfferCatalog
    from pydantic2_schemaorg.GenderType import GenderType
    from pydantic2_schemaorg.Distance import Distance
    from pydantic2_schemaorg.Grant import Grant
    from pydantic2_schemaorg.PostalAddress import PostalAddress



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class SendAction(TransferAction):
    """The act of physically/electronically dispatching an object for transfer from an origin to a destination.
     Related actions: * [[ReceiveAction]]: The reciprocal of SendAction. * [[GiveAction]]: Unlike GiveAction,
     SendAction does not imply the transfer of ownership (e.g. I can send you my laptop, but I'm not necessarily
     giving it to you).

    See: https://schema.org/SendAction
    Model depth: 4
    """

    type_: str = Field(default="SendAction", alias="@type", const=True)
    recipient: Optional[
        Union[
            List[Union["Organization", "Audience", "Person", "ContactPoint", str]],
            "Organization",
            "Audience",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the receiving end of the action.",
    )
    deliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="A sub property of instrument. The method of delivery.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class BroadcastChannel(Intangible):
    """A unique instance of a BroadcastService on a CableOrSatelliteService lineup.

    See: https://schema.org/BroadcastChannel
    Model depth: 3
    """

    type_: str = Field(default="BroadcastChannel", alias="@type", const=True)
    genre: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description="Genre of the creative work, broadcast channel or group.",
    )
    broadcastServiceTier: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The type of service required to have access to the channel (e.g. Standard or Premium).",
        )
    )
    broadcastFrequency: Optional[
        Union[
            List[Union[str, "Text", "BroadcastFrequencySpecification"]],
            str,
            "Text",
            "BroadcastFrequencySpecification",
        ]
    ] = Field(
        default=None,
        description='The frequency used for over-the-air broadcasts. Numeric values or simple ranges, e.g. 87-99. In addition a shortcut idiom is supported for frequencies of AM and FM radio channels, e.g. "87 FM".',
    )
    providesBroadcastService: Optional[
        Union[List[Union["BroadcastService", str]], "BroadcastService", str]
    ] = Field(
        default=None,
        description="The BroadcastService offered on this channel.",
    )
    broadcastChannelId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The unique address by which the BroadcastService can be identified in a provider lineup. In US, this is typically a number.",
    )
    inBroadcastLineup: Optional[
        Union[
            List[Union["CableOrSatelliteService", str]], "CableOrSatelliteService", str
        ]
    ] = Field(
        default=None,
        description="The CableOrSatelliteService offering the channel.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.BroadcastFrequencySpecification import (
        BroadcastFrequencySpecification,
    )
    from pydantic2_schemaorg.BroadcastService import BroadcastService
    from pydantic2_schemaorg.CableOrSatelliteService import CableOrSatelliteService



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalIndication import MedicalIndication


class TreatmentIndication(MedicalIndication):
    """An indication for treating an underlying condition, symptom, etc.

    See: https://schema.org/TreatmentIndication
    Model depth: 4
    """

    type_: str = Field(default="TreatmentIndication", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Atlas(CreativeWork):
    """A collection or bound volume of maps, charts, plates or tables, physical or in media form illustrating any
     subject.

    See: https://schema.org/Atlas
    Model depth: 3
    """

    type_: str = Field(default="Atlas", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.UKNonprofitType import UKNonprofitType


class LimitedByGuaranteeCharity(UKNonprofitType):
    """LimitedByGuaranteeCharity: Non-profit type referring to a charitable company that is limited by guarantee
     (UK).

    See: https://schema.org/LimitedByGuaranteeCharity
    Model depth: 6
    """

    type_: str = Field(default="LimitedByGuaranteeCharity", alias="@type", const=True)
